package com.yiqi.core.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.core.domain.ClothRewashReasonType;

/**
 * 衣服重洗原因类别Mapper接口
 *
 * @author ruoyi
 * @date 2023-09-23
 */
public interface ClothRewashReasonTypeMapper extends BaseMapper<ClothRewashReasonType> {
    /**
     * 查询衣服重洗原因类别
     *
     * @param id 衣服重洗原因类别主键
     * @return 衣服重洗原因类别
     */
    public ClothRewashReasonType selectClothRewashReasonTypeById(Long id);

    /**
     * 查询衣服重洗原因类别列表
     *
     * @param clothRewashReasonType 衣服重洗原因类别
     * @return 衣服重洗原因类别集合
     */
    public List<ClothRewashReasonType> selectClothRewashReasonTypeList(ClothRewashReasonType clothRewashReasonType);

    /**
     * 新增衣服重洗原因类别
     *
     * @param clothRewashReasonType 衣服重洗原因类别
     * @return 结果
     */
    public int insertClothRewashReasonType(ClothRewashReasonType clothRewashReasonType);

    /**
     * 修改衣服重洗原因类别
     *
     * @param clothRewashReasonType 衣服重洗原因类别
     * @return 结果
     */
    public int updateClothRewashReasonType(ClothRewashReasonType clothRewashReasonType);

    /**
     * 删除衣服重洗原因类别
     *
     * @param id 衣服重洗原因类别主键
     * @return 结果
     */
    public int deleteClothRewashReasonTypeById(Long id);

    /**
     * 批量删除衣服重洗原因类别
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteClothRewashReasonTypeByIds(Long[] ids);
}
